@@ -1,8 +1,8 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ultisnips-mode" "1.0.1"
+(define-package "ultisnips-mode" "20260203.255"
   "Major mode for editing Ultisnips snippets."
   '((emacs "26.3"))
   :url "https://github.com/jamescherti/ultisnips-mode.el"
-  :commit "035cacccebe1629eca5ce24fd6f597a4e5453d23"
-  :revdesc "1.0.1-0-g035cacccebe1"
+  :commit "6b66405bb5e72e02d0f2df83d5918b499c564b2a"
+  :revdesc "6b66405bb5e7"
   :keywords '("languages"))
